astrodendro.analysis
====================

.. currentmodule:: astrodendro.analysis

.. autoclass:: PPStatistic

.. rubric:: Available statistics

.. autosummary::

      ~PPStatistic.flux
      ~PPStatistic.major_sigma
      ~PPStatistic.minor_sigma
      ~PPStatistic.position_angle
      ~PPStatistic.radius
      ~PPStatistic.area_exact
      ~PPStatistic.area_ellipse
      ~PPStatistic.x_cen
      ~PPStatistic.y_cen
      ~PPStatistic.to_mpl_ellipse

.. rubric:: Methods (detail)

.. automethod:: PPStatistic.to_mpl_ellipse

.. autoclass:: PPVStatistic

.. rubric:: Available statistics

.. autosummary::

      ~PPVStatistic.flux
      ~PPVStatistic.major_sigma
      ~PPVStatistic.minor_sigma
      ~PPVStatistic.position_angle
      ~PPVStatistic.radius
      ~PPStatistic.area_exact
      ~PPStatistic.area_ellipse
      ~PPVStatistic.x_cen
      ~PPVStatistic.y_cen
      ~PPVStatistic.v_cen
      ~PPVStatistic.v_rms
      ~PPVStatistic.to_mpl_ellipse

.. rubric:: Methods (detail)

.. automethod:: PPStatistic.to_mpl_ellipse

.. autofunction:: pp_catalog

.. autofunction:: ppv_catalog

